@@ -28,12 +28,16 @@
     #mar <- c(5.1,4.1,4.1,2.1)
     #bty <- "l"
     #}
+    log <- if(par("ylog")) "y" else ""
     if (missing(ylim))
       ylim <- range(c(0,val$values),na.rm=TRUE)*1.04
     else if(length(ylim) == 1)
       ylim <- c(0,ylim)
+    if(log=="y")
+      ylim[1] <- min(val$values,na.rm=TRUE)
+    par(xaxs="r",yaxt="n",xaxt="n")
     frame()
-    plot.window(xlim=c(0.5,num+0.5),ylim=ylim)
+    plot.window(xlim=c(0.5,num+0.5),ylim=ylim,log=log)
     if(start != 1){
       warning("'start' not yet supported; must be 1 for now")
       start <- 1
@@ -43,14 +47,18 @@
       rep <- 0
     }
     .seasmonthgrid(x$width,x$bin.lengths,start,rep,x$start.day)
-    pl <- suppressWarnings(boxplot(by(val,val$ind,function(x)x$values),
-                                   xlab=xlab,ylab=ylab[1],varwidth=TRUE,
-                                   add=TRUE,col=col,main=main))
+    op <- getOption("seas.bxp")
+    pl <- boxplot(values ~ ind,val,col=col,varwidth=TRUE,names=NA,
+                  add=TRUE,outcex=op$outcex*par("cex"))
     #if(add.alt) {
     #  alt.ax <- pretty(ylim*slope+inter)
     #  axis(side=4,at=(alt.ax-inter)/slope,lab=alt.ax,srt=90)
     #  if(!is.na(ylab[2]))
     #    mtext(ylab[2],side=4,line=2.8)
     #}
+    par(yaxt="s",xaxt="s")
+    axis(2,lwd=par("lwd"))
+    axis(1,1:num,x$bins,lwd=par("lwd"))
+    title(main,xlab=xlab,ylab=ylab[1])
     invisible(pl)
   }
